@@ -12,7 +12,6 @@ pub fn cmd() -> Cmd {
                 .short('n')
                 .about("Specify the app name")
                 .takes_value(true),
-            Arg::new("warning").short('w').about("Enable warning"),
             Arg::new("verbose").short('v').about("Enable verbose"),
             Arg::new("debug").short('d').about("Enable debug"),
         ])
@@ -20,26 +19,23 @@ pub fn cmd() -> Cmd {
 
 pub fn exec(config: &Config, args: &clap::ArgMatches) -> CmdResult {
     let app_name = args.value_of("name").map(|app_name| app_name.to_owned());
-    let warning = args.is_present("warning");
     let verbose = args.is_present("verbose");
     let debug = args.is_present("debug");
-    let opts = CheckOptions::new(app_name, warning, verbose, debug);
+    let opts = CheckOptions::new(app_name, verbose, debug);
     do_exec(config, &opts)?;
     Ok(())
 }
 
 pub struct CheckOptions {
     app_name: Option<String>,
-    warning: bool,
     verbose: bool,
     debug: bool,
 }
 
 impl CheckOptions {
-    pub fn new(app_name: Option<String>, warning: bool, verbose: bool, debug: bool) -> Self {
+    pub fn new(app_name: Option<String>, verbose: bool, debug: bool) -> Self {
         CheckOptions {
             app_name,
-            warning,
             verbose,
             debug,
         }
@@ -49,10 +45,6 @@ impl CheckOptions {
         self.app_name.as_ref()
     }
 
-    pub fn warning(&self) -> bool {
-        self.warning
-    }
-
     pub fn verbose(&self) -> bool {
         self.verbose
     }
